package com.mrcrayfish.furniture.api;

import java.util.HashMap;

/**
 * Different recipes require certain variables for them to be registered. Some
 * recipes have optional variables which you can add but is not required. If the
 * required variables are not present, your custom recipe will be discarded.
 * Below is a table which should help you add the correct variables.
 * <table border="2">
 * <tr>
 * <TH>Type</TH>
 * <TH>Required Variables</TH>
 * <TH>Optional Variables</TH>
 * </tr>
 * <tr>
 * <td>Freezer</td>
 * <td>input (ItemStack), output (ItemStack)</td>
 * </tr>
 * <tr>
 * <td>Oven</td>
 * <td>input (ItemStack), output (ItemStack)</td>
 * </tr>
 * <tr>
 * <td>Printer</td>
 * <td>input (ItemStack)</td>
 * </tr>
 * <tr>
 * <td>MineBay</td>
 * <td>input (ItemStack)</td>
 * <td>currency (ItemStack), price (Integer)</td>
 * </tr>
 * <tr>
 * <td>Toaster</td>
 * <td>input (ItemStack), output (ItemStack)</td>
 * </tr>
 * <tr>
 * <td>Chopping Board</td>
 * <td>input (ItemStack), output (ItemStack)</td>
 * </tr>
 * <tr>
 * <td>Blender</td>
 * <td>name (String), heal (Integer), ingredients (ItemStack[]), colour (int[])</td>
 * </tr>
 * <tr>
 * <td>Dishwasher</td>
 * <td>input (ItemStack)</td>
 * </tr>
 * <tr>
 * <td>Washing Machine</td>
 * <td>input (ItemStack)</td>
 * </tr>
 * <tr>
 * <td>Microwave</td>
 * <td>input (ItemStack), output(ItemStack)</td>
 * </tr>
 * </table>
 * <br>
 * <br>
 * For example, an oven recipe might look like this.<br>
 * <br>
 * <i>RecipeVariables recipe = new RecipeVariables(); <br>
 * recipe.addValue("input", new ItemStack(Items.beef)); <br>
 * recipe.addValue("output", new ItemStack(Items.cooked_beef)); <br>
 * registry.registerRecipe("oven", recipe);</i> <br>
 * <br>
 * or<br>
 * <br>
 * <i>registry.registerRecipe("oven", new RecipeVariables().addValue("input",
 * new ItemStack(Items.beef)).addValue("output", new
 * ItemStack(Items.cooked_beef)));</i> <br>
 * <br>
 * For a full tutorial, <a
 * href="http://mrcrayfishs-furniture-mod.wikia.com/wiki/Developers">click
 * here</a>.
 * 
 * @author MrCrayfish
 *
 */
public class RecipeVariables extends HashMap<String, Object> {
	/**
	 * Adds a value to the recipe variables
	 * 
	 * @param variable
	 *            The type of variable
	 * @param object
	 *            The object to bind to the variable
	 * @return RecipeVariables instance
	 * 
	 * @see {@link RecipeVariables} for required variables
	 * */
	public RecipeVariables addValue(String variable, Object object) {
		this.put(variable, object);
		return this;
	}
}
